hostexec

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 20, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Overview

Package hostexec automatically wraps commands executed with kubernetes hostexec into chrooted commands

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Executor

type Executor interface {
	Command(string, ...string) exec.Cmd
	CommandContext(context.Context, string, ...string) exec.Cmd
}

Executor is mostly k8s.io/utils/exec compatible interface for the portions that synology-csi uses.

func New

func New(cmdMap map[string]string, chrootDir string) (Executor, error)

New creates an instance of hostexec to execute commands in the given environment

Jump to